@@ -1,10 +1,8 @@
 from ctypes import *
 import os
-import platform
 import numpy as np
 
-lib_version = platform.linux_distribution()
-assert lib_version[0].lower() == 'ubuntu'
+
 lib_path = os.path.join(
     os.path.dirname(os.path.realpath(__file__)),
     'so/libdetect.so')
